==> webissues_0.9.1.dfsg.1.orig.tar.gz: webissues-0.9.1.dfsg.1/src/application.h <==
/**************************************************************************
* This file is part of the WebIssues program
* Copyright (C) 2006 Michał Męciński
* Copyright (C) 2007 WebIssues Team
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
**************************************************************************/

#ifndef APPLICATION_H
#define APPLICATION_H

#include <QApplication>

class QUrl;

/**
* The main namespace of the WebIssues application.
*/
namespace WebIssues
{

class MainWindow;

/**
* Class representing the WebIssues application.
*
* On startup the application creates the ConfigData
* and ConnectionManager objects, opens the MainWindow
* and restores the session or the last connection if necessary.
*
* On shutdown it destroys all objects.
*/
class Application : public QApplication
{
    Q_OBJECT
public:
    /**
    * Constructor.
    */
    Application( int& argc, char** argv );

    /**
    * Destructor.
    */
    ~Application();

public:
    /**
    * Return the URL of the manual index;
    */
    QUrl manualIndex() const;

public slots:
    /**
    * Show the About WebIssues dialog.
    */
    void about();

    /**
    * Open the WebIssues manual.
    */
    void manual();

public: // overrides
    void commitData( QSessionManager& manager );

private:
    MainWindow* m_mainWindow;

    QString m_manualPath;
};

}

#endif

==> webissues_0.9.2.orig.tar.gz: webissues-0.9.2/src/application.h <==
/**************************************************************************
* This file is part of the WebIssues program
* Copyright (C) 2006 Michał Męciński
* Copyright (C) 2007-2008 WebIssues Team
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
**************************************************************************/

#ifndef APPLICATION_H
#define APPLICATION_H

#include <QApplication>

class QUrl;

/**
* The main namespace of the WebIssues application.
*/
namespace WebIssues
{

class MainWindow;

/**
* Class representing the WebIssues application.
*
* On startup the application creates the ConfigData
* and ConnectionManager objects, opens the MainWindow
* and restores the session or the last connection if necessary.
*
* On shutdown it destroys all objects.
*/
class Application : public QApplication
{
    Q_OBJECT
public:
    /**
    * Constructor.
    */
    Application( int& argc, char** argv );

    /**
    * Destructor.
    */
    ~Application();

public:
    /**
    * Return the URL of the manual index;
    */
    QUrl manualIndex() const;

    /**
    * Return the version of the application.
    */
    QString version() const;

public slots:
    /**
    * Show the About WebIssues dialog.
    */
    void about();

    /**
    * Open the WebIssues manual.
    */
    void manual();

public: // overrides
    void commitData( QSessionManager& manager );

private:
    bool loadTranslation( const QString& name, bool tryQtDir );

private:
    MainWindow* m_mainWindow;

    QString m_manualPath;
    QString m_translationsPath;
};

}

#endif
